<?php
namespace Service;

use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\ORM\DateTime;

class ErpService extends \Zeedhi\Framework\Controller\Simple {

    protected $connection;
    protected $entityManager;

    public function __construct(\Doctrine\ORM\EntityManager $entityManager)  {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    
    /**
     * Método base
     */
    public function baseApi($row){
        try{
            $query = "SELECT CDOPERADOR, NMOPERADOR FROM OPERADOR
						WHERE CDOPERADOR = :P_CDOPERADOR";
	
			$params = array(
                'P_CDOPERADOR' => $row['CDOPERADOR']
            );
            return $this->entityManager->getConnection()->fetchAll($query, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * consumirOPEmAndamento
     */
    public function consumirOPEmAndamento() {
        try {
            
            $arrayOps = array();
            $ops = $this->getOps();
            
            foreach($ops as $op){
                $opCompleta = $op;
                $opCompleta['INSUMO'] = $this->getItens($op);
                array_push($arrayOps, $opCompleta);
            }
            
            return $arrayOps;
            
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getOps(){
        try{
            $queryOps = "SELECT O.NRORG,
                          O.CDFILIAL,
                          O.NRORDPROD,
                          O.NRSUBORDPROD,
                          P.CDARVPROD                                                                       AS CDFICHA,
                          P.CDPRODINTE                                                                      AS CODCMFICHA,
                          P.NMPRODUTO                                                                       AS NOMEFICHA,
                          P.SGUNIDADE                                                                       AS UNIDMEDFICHA,
                          TO_CHAR(O.DTGERORDPROD, 'DD/MM/YYYY')                                             AS DATAGERACAOOP,
                          TO_CHAR(O.DTHRINICIAOP, 'DD/MM/YYYY')                                             AS DATAINICIO,
                          TO_CHAR(O.DTHRFIMPREOP, 'DD/MM/YYYY')                                             AS DATAFINAL,
                          REPLACE(TO_CHAR(O.QTAPRODPREOP, '999999999999999.999'), ' ','')                   AS QTPLANEJADA,
                          REPLACE(TO_CHAR(RENDIMENTO_RECEITA_CDP(O.CDFILIAL, O.CDPRODUTO), '999999999999999.99999'), ' ','') AS RENDIMENTO,
                          S.NMSETOR                                                                         AS CDSETOR,
                          F.CDCENTCUST
                        FROM ORDPRODUCAO O
                        INNER JOIN PRODUTO P
                        ON O.CDPRODUTO = P.CDPRODUTO
                        INNER JOIN FILIAL F
                        ON O.CDFILIAL = F.CDFILIAL
                        LEFT JOIN SETOR S
                        ON O.CDSETORESPOP = S.CDSETOR
                        WHERE O.IDSITORDPROD = '2'
                        ORDER BY O.NRORDPROD";

			$params = array();
            $ops = $this->entityManager->getConnection()->fetchAll($queryOps, $params);
            return $ops;
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getItens($op){
        try{
            $queryItens = "SELECT PI.CDARVPROD                                      AS CODITEM,
                                  PI.NMPRODUTO                                      AS INSUMO,
                                  PI.CDPRODINTE                                     AS CODCM,
                                  PI.SGUNIDADE                                      AS UNIDMED,
                                  REPLACE(TO_CHAR(PI.VRPESOBRUTPR, '999999999999999.99999'), ' ','') AS VRPESOUNID,
                                  REPLACE(TO_CHAR(I.QTPRERETPROD, '999999999999999.99999'), ' ','') AS QTPREVISTA,
                                  'INSUMO PREVISTO OP '||O.NRORDPROD||'/'||O.NRSUBORDPROD AS DSLANCESTIT
                                FROM ORDPRODUCAO O
                                LEFT JOIN RETIRADAESTO R
                                ON O.CDFILIAL      = R.CDFILIAL
                                AND O.NRORDPROD    = R.NRORDPROD
                                AND O.NRSUBORDPROD = R.NRSUBORDPROD
                                LEFT JOIN ITEMRETIEST I
                                ON R.CDFILIAL  = I.CDFILIAL
                                AND R.NRRETEST = I.NRRETEST
                                INNER JOIN PRODUTO PI
                                ON I.CDPRODUTO   = PI.CDPRODUTO
                                WHERE O.CDFILIAL = :P_CDFILIAL
                                AND O.NRORDPROD  = :P_NRORDPROD";
			$params = array(
                'P_CDFILIAL'    => $op['CDFILIAL'],
                'P_NRORDPROD'   => $op['NRORDPROD']
            );
            $itens = $this->entityManager->getConnection()->fetchAll($queryItens, $params);
            return $itens;
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
}