<?php
namespace tests\Zeedhi\Framework\DB\Procedure\Strategies;

use Zeedhi\Framework\DB\StoredProcedure\Strategies\SQLServerStrategy;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

use Doctrine\DBAL\Connection;
use Doctrine\DBAL\Driver\SQLSrv\SQLSrvStatement;

class SQLServerStrategyTest extends \PHPUnit_Framework_TestCase {

    public function setUp() {
        if (!defined('SQLSRV_PARAM_IN')) {
            $this->markTestSkipped("Missing SQL Server extension.");
        }

        $this->connection = $this->getMockBuilder(Connection::class)
                                 ->setMethods(array('prepare'))
                                 ->disableOriginalConstructor()
                                 ->getMock();

        $this->sqlServerStrategy = new SQLServerStrategy($this->connection);
    }

    public function testExecuteProcedureWithParamInAndOut() {
        $params = array(
            new Param('param1', Param::PARAM_INPUT, 'value'),
            new Param('param2', Param::PARAM_OUTPUT)
        );
        $procedure = new StoredProcedure($this->connection, 'procedure', $params);

        $statement = $this->getMockBuilder(SQLSrvStatement::class)
                          ->setMethods(array('execute'))
                          ->disableOriginalConstructor()
                          ->getMock();

        $this->connection->expects($this->once())
                         ->method('prepare')
                         ->with('EXECUTE procedure @param1 = ? , @param2 = ? ')
                         ->will($this->returnValue($statement));

        $statement->expects($this->once())
            ->method('execute')
            ->with($this->callback(function($params) {
                $valid = $params[1][0] == 'value'
                    && $params[1][1] == SQLSRV_PARAM_IN
                    && $params[2][0] == null
                    && $params[2][1] == SQLSRV_PARAM_OUT;

                $params[1][0] = 'input value';
                $params[2][0] = 'output value';

                return $valid;
            }))
            ->will($this->returnValue(true));

        $outputParams = $this->sqlServerStrategy->executeProcedure($procedure);

        $this->assertCount(2, $outputParams);

        $this->assertArrayHasKey('param1', $outputParams);
        $this->assertArrayHasKey('param2', $outputParams);

        $this->assertEquals($outputParams['param1'], 'input value');
        $this->assertEquals($outputParams['param2'], 'output value');
    }

}